@@ -96,6 +96,8 @@ struct symbol_table symbol_table = { 0, 0, 0, /* for stacked module support */
 	X(namei),
 	X(lnamei),
 	X(open_namei),
+	X(inode_setattr),
+	X(inode_change_ok),
 
 	/* device registration */
 	X(register_chrdev),
@@ -212,7 +214,7 @@ struct symbol_table symbol_table = { 0, 0, 0, /* for stacked module support */
 	/* for the nec cdr-260 cdrom drive */
 	X (the_nec260_major),
 	X (do_hd),
-        X (read_ahead),
+	X (read_ahead),
 	X (sync_dev),
 	X (invalidate_buffers),
 	X (__down),
@@ -221,6 +223,7 @@ struct symbol_table symbol_table = { 0, 0, 0, /* for stacked module support */
 #endif
 #endif
 
+
 	/********************************************************
 	 * Do not add anything below this line,
 	 * as the stacked modules depend on this!
